# Emblem

[shields.io](https://shields.io/) from the command line, plus niceties. Test coverage badges for now.

```
emblem 80% --label "Coverage badges for now" --colors lightgrey purple --logo latex --fname ./test.svg
```

![](test.svg)